@@ -17,6 +17,7 @@
 #include <libcamera/control_ids.h>
 #include <libcamera/controls.h>
 #include <libcamera/geometry.h>
+#include <libcamera/ipa/core_ipa_interface.h>
 
 #include <libipa/camera_sensor_helper.h>
 #include <libipa/fc_queue.h>
@@ -31,6 +32,7 @@ struct IPAHwSettings {
 	unsigned int numHistogramBins;
 	unsigned int numHistogramWeights;
 	unsigned int numGammaOutSamples;
+	bool compand;
 };
 
 struct IPASessionConfiguration {
@@ -59,6 +61,7 @@ struct IPASessionConfiguration {
 	} sensor;
 
 	bool raw;
+	uint32_t paramFormat;
 };
 
 struct IPAActiveState {
@@ -178,6 +181,7 @@ struct IPAFrameContext : public FrameContext {
 
 struct IPAContext {
 	const IPAHwSettings *hw;
+	IPACameraSensorInfo sensorInfo;
 	IPASessionConfiguration configuration;
 	IPAActiveState activeState;
 
