@@ -10,7 +10,6 @@
 #include <algorithm>
 #include <array>
 #include <fcntl.h>
-#include <iomanip>
 #include <sstream>
 #include <string.h>
 #include <sys/ioctl.h>
@@ -1841,7 +1840,7 @@ FrameBuffer *V4L2VideoDevice::dequeueBuffer()
 	 * Detect kernel drivers which do not reset the sequence number to zero
 	 * on stream start.
 	 */
-	if (!firstFrame_) {
+	if (!firstFrame_.has_value()) {
 		if (buf.sequence)
 			LOG(V4L2, Info)
 				<< "Zero sequence expected for first frame (got "
